@@ -720,7 +720,7 @@ get_ticket_sync (GoaKerberosProvider *self,
     }
 
   memset (&request, 0, sizeof (SignInRequest));
-  request.loop = g_main_loop_new (g_main_context_get_thread_default (), FALSE);
+  request.loop = g_main_loop_new (NULL, FALSE);
   request.error = NULL;
 
   sign_in_identity (self,
@@ -754,12 +754,12 @@ notify_is_temporary_cb (GObject *object, GParamSpec *pspec, gpointer user_data)
   GoaAccount *account;
   gboolean is_temporary;
 
+  /* Toggle IsTemporary */
+  goa_util_account_notify_property_cb (object, pspec, "IsTemporary");
+
   account = GOA_ACCOUNT (object);
   g_object_get (account, "is-temporary", &is_temporary, NULL);
 
-  /* Toggle IsTemporary */
-  goa_utils_keyfile_set_boolean (account, "IsTemporary", is_temporary);
-
   /* Set/unset SessionId */
   if (is_temporary)
     {
@@ -1631,8 +1631,6 @@ start_over:
       goto start_over;
     }
 
-  goa_account_set_is_temporary (account, FALSE);
-
   gtk_widget_hide (GTK_WIDGET (dialog));
 
  out:
@@ -1781,6 +1779,9 @@ on_identity_looked_up_to_ensure_credentials (GoaKerberosProvider *self,
                     (GAsyncReadyCallback)
                     on_identity_looked_up,
                     operation_result);
+
+  g_simple_async_result_complete_in_idle (operation_result);
+  g_object_unref (operation_result);
 }
 
 static void
