@@ -30,6 +30,10 @@
 #include "goaexchangeprovider.h"
 #include "goagoogleprovider.h"
 #include "goafacebookprovider.h"
+#include "goaowncloudprovider.h"
+#include "goayahooprovider.h"
+#include "goatwitterprovider.h"
+#include "goaflickrprovider.h"
 #include "goawindowsliveprovider.h"
 
 #ifdef GOA_KERBEROS_ENABLED
@@ -37,7 +41,6 @@
 #endif
 
 #include "goaeditablelabel.h"
-#include "goautils.h"
 
 /**
  * SECTION:goaprovider
@@ -279,16 +282,18 @@ goa_provider_refresh_account (GoaProvider  *provider,
  * @provider: A #GoaProvider.
  * @client: A #GoaClient.
  * @object: A #GoaObject with a #GoaAccount interface.
- * @dialog: A #GtkDialog.
  * @vbox: A vertically oriented #GtkBox to put content in.
- * @table: A table which is the first element of vbox.
+ * @left: A vertically oriented #GtkGrid to put left-aligned content
+ * in.
+ * @right: A vertically oriented #GtkGrid to put right-aligned content
+ * in.
  *
  * Method used to add widgets in the control panel for the account
  * represented by @object.
  *
  * This is a virtual method with an implementation that (currently)
  * does nothing. A subclass should chain up (before adding their own
- * widgets to @vbox and @table) if they want to expose such
+ * widgets to @vbox, @left and @right) if they want to expose such
  * functionality.
  */
 void
@@ -435,7 +440,7 @@ ensure_credentials_in_thread_func (GSimpleAsyncResult *simple,
  * of the operation.
  *
  * This is a virtual method where the default implementation simply
- * returns the %GOA_ERROR_NOT_SUPPORTED error. A subclass may provide
+ * throws the %GOA_ERROR_NOT_SUPPORTED error. A subclass may provide
  * another implementation.
  */
 void
@@ -620,9 +625,15 @@ ensure_ep_and_builtins (void)
 #ifdef GOA_GOOGLE_ENABLED
       type = GOA_TYPE_GOOGLE_PROVIDER;
 #endif
+#ifdef GOA_OWNCLOUD_ENABLED
+      type = GOA_TYPE_OWNCLOUD_PROVIDER;
+#endif
 #ifdef GOA_FACEBOOK_ENABLED
       type = GOA_TYPE_FACEBOOK_PROVIDER;
 #endif
+#ifdef GOA_FLICKR_ENABLED
+      type = GOA_TYPE_FLICKR_PROVIDER;
+#endif
 #ifdef GOA_WINDOWS_LIVE_ENABLED
       type = GOA_TYPE_WINDOWS_LIVE_PROVIDER;
 #endif
@@ -632,6 +643,12 @@ ensure_ep_and_builtins (void)
 #ifdef GOA_KERBEROS_ENABLED
       type = GOA_TYPE_KERBEROS_PROVIDER;
 #endif
+#ifdef GOA_YAHOO_ENABLED
+      type = GOA_TYPE_YAHOO_PROVIDER;
+#endif
+#ifdef GOA_TWITTER_ENABLED
+      type = GOA_TYPE_TWITTER_PROVIDER;
+#endif
 
       type = type; /* silence -Wunused-but-set-variable */
 
@@ -864,6 +881,56 @@ goa_util_lookup_keyfile_boolean (GoaObject    *object,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
+static void
+goa_util_set_keyfile_boolean (GoaAccount *account, const gchar *key, gboolean value)
+{
+  GError *error;
+  GKeyFile *key_file;
+  gchar *contents;
+  gchar *group;
+  gchar *path;
+  gsize length;
+
+  contents = NULL;
+
+  path = g_strdup_printf ("%s/goa-1.0/accounts.conf", g_get_user_config_dir ());
+  group = g_strdup_printf ("Account %s", goa_account_get_id (account));
+
+  key_file = g_key_file_new ();
+  error = NULL;
+  if (!g_key_file_load_from_file (key_file,
+                                  path,
+                                  G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS,
+                                  &error))
+    {
+      goa_warning ("Error loading keyfile %s: %s (%s, %d)",
+                   path,
+                   error->message,
+                   g_quark_to_string (error->domain),
+                   error->code);
+      g_error_free (error);
+      goto out;
+    }
+
+  g_key_file_set_boolean (key_file, group, key, value);
+  contents = g_key_file_to_data (key_file, &length, NULL);
+
+  error = NULL;
+  if (!g_file_set_contents (path, contents, length, &error))
+    {
+      g_prefix_error (&error, "Error writing key-value-file %s: ", path);
+      goa_warning ("%s (%s, %d)", error->message, g_quark_to_string (error->domain), error->code);
+      g_error_free (error);
+      goto out;
+    }
+
+ out:
+  g_free (contents);
+  g_key_file_free (key_file);
+  g_free (group);
+  g_free (path);
+}
+
 void
 goa_util_account_notify_property_cb (GObject *object, GParamSpec *pspec, gpointer user_data)
 {
@@ -879,7 +946,7 @@ goa_util_account_notify_property_cb (GObject *object, GParamSpec *pspec, gpointe
   name = g_param_spec_get_name (pspec);
 
   g_object_get (account, name, &value, NULL);
-  goa_utils_keyfile_set_boolean (account, key, !value);
+  goa_util_set_keyfile_boolean (account, key, !value);
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
